@@ -21,6 +21,7 @@
 
 import gettext
 
-__version__ = "2.1.5"
+__version__: str = "3.0.2"
+__reldate__: str = "August 09, 2024"
 
 gettext.install("duplicity", names=["ngettext"])
